==> kdevplatform-5.0.3-1-x86_64.pkg.tar.xz: usr/lib/cmake/KDevPlatform/KDevPlatformTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDev::Sublime" for configuration "Release"
set_property(TARGET KDev::Sublime APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Sublime PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::KIOWidgets"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformSublime.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformSublime.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Sublime )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Sublime "${_IMPORT_PREFIX}/lib/libKDevPlatformSublime.so.10.0.0" )

# Import target "KDev::Interfaces" for configuration "Release"
set_property(TARGET KDev::Interfaces APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Interfaces PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::ConfigCore;KF5::I18n;KF5::Service"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformInterfaces.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformInterfaces.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Interfaces )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Interfaces "${_IMPORT_PREFIX}/lib/libKDevPlatformInterfaces.so.10.0.0" )

# Import target "KDev::Project" for configuration "Release"
set_property(TARGET KDev::Project APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Project PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Serialization;KDev::Vcs;KF5::KIOWidgets;Qt5::Concurrent"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformProject.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformProject.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Project )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Project "${_IMPORT_PREFIX}/lib/libKDevPlatformProject.so.10.0.0" )

# Import target "KDev::Language" for configuration "Release"
set_property(TARGET KDev::Language APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Language PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::GuiAddons;KF5::TextEditor;KF5::Parts;KF5::Archive;KF5::IconThemes;KDev::Util;KDev::Project;Grantlee5::Templates"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformLanguage.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformLanguage.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Language )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Language "${_IMPORT_PREFIX}/lib/libKDevPlatformLanguage.so.10.0.0" )

# Import target "KDev::Shell" for configuration "Release"
set_property(TARGET KDev::Shell APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Shell PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt5::Quick;Qt5::QuickWidgets;KF5::GuiAddons;KF5::IconThemes;KF5::KIOFileWidgets;KF5::KIOWidgets;KF5::Parts;KF5::Notifications;KF5::NotifyConfig;KF5::TextEditor;KF5::ThreadWeaver;KF5::JobWidgets;KF5::ItemViews;KF5::WindowSystem;KF5::KCMUtils;KF5::NewStuff;KF5::Archive;KDev::Debugger;KDev::Project;KDev::Vcs;KDev::Language;KDev::Util;KDev::Documentation"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformShell.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformShell.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Shell )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Shell "${_IMPORT_PREFIX}/lib/libKDevPlatformShell.so.10.0.0" )

# Import target "KDev::Util" for configuration "Release"
set_property(TARGET KDev::Util APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Util PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::ConfigWidgets;KF5::TextEditor;KF5::GuiAddons"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformUtil.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformUtil.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Util )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Util "${_IMPORT_PREFIX}/lib/libKDevPlatformUtil.so.10.0.0" )

# Import target "KDev::OutputView" for configuration "Release"
set_property(TARGET KDev::OutputView APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::OutputView PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformOutputView.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformOutputView.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::OutputView )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::OutputView "${_IMPORT_PREFIX}/lib/libKDevPlatformOutputView.so.10.0.0" )

# Import target "KDev::Vcs" for configuration "Release"
set_property(TARGET KDev::Vcs APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Vcs PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::KIOWidgets;KF5::Parts;KDev::Util"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformVcs.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformVcs.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Vcs )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Vcs "${_IMPORT_PREFIX}/lib/libKDevPlatformVcs.so.10.0.0" )

# Import target "KDev::Debugger" for configuration "Release"
set_property(TARGET KDev::Debugger APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Debugger PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt5::Core;KF5::Notifications;KF5::TextEditor;KDev::Sublime"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformDebugger.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformDebugger.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Debugger )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Debugger "${_IMPORT_PREFIX}/lib/libKDevPlatformDebugger.so.10.0.0" )

# Import target "KDev::Documentation" for configuration "Release"
set_property(TARGET KDev::Documentation APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Documentation PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformDocumentation.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformDocumentation.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Documentation )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Documentation "${_IMPORT_PREFIX}/lib/libKDevPlatformDocumentation.so.10.0.0" )

# Import target "KDev::Serialization" for configuration "Release"
set_property(TARGET KDev::Serialization APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Serialization PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Util"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformSerialization.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformSerialization.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Serialization )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Serialization "${_IMPORT_PREFIX}/lib/libKDevPlatformSerialization.so.10.0.0" )

# Import target "KDev::Tests" for configuration "Release"
set_property(TARGET KDev::Tests APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Tests PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt5::Core;Qt5::Test"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformTests.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformTests.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Tests )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Tests "${_IMPORT_PREFIX}/lib/libKDevPlatformTests.so.10.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kdevplatform-5.1.2-1-x86_64.pkg.tar.xz: usr/lib/cmake/KDevPlatform/KDevPlatformTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDev::Sublime" for configuration "Release"
set_property(TARGET KDev::Sublime APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Sublime PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::KIOWidgets"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformSublime.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformSublime.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Sublime )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Sublime "${_IMPORT_PREFIX}/lib/libKDevPlatformSublime.so.10.0.0" )

# Import target "KDev::Interfaces" for configuration "Release"
set_property(TARGET KDev::Interfaces APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Interfaces PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::ConfigCore;KF5::I18n;KF5::Service"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformInterfaces.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformInterfaces.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Interfaces )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Interfaces "${_IMPORT_PREFIX}/lib/libKDevPlatformInterfaces.so.10.0.0" )

# Import target "KDev::Project" for configuration "Release"
set_property(TARGET KDev::Project APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Project PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Serialization;KDev::Vcs;KF5::KIOWidgets;Qt5::Concurrent"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformProject.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformProject.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Project )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Project "${_IMPORT_PREFIX}/lib/libKDevPlatformProject.so.10.0.0" )

# Import target "KDev::Language" for configuration "Release"
set_property(TARGET KDev::Language APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Language PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::GuiAddons;KF5::TextEditor;KF5::Parts;KF5::Archive;KF5::IconThemes;KDev::Util;KDev::Project;Grantlee5::Templates"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformLanguage.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformLanguage.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Language )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Language "${_IMPORT_PREFIX}/lib/libKDevPlatformLanguage.so.10.0.0" )

# Import target "KDev::Shell" for configuration "Release"
set_property(TARGET KDev::Shell APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Shell PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::GuiAddons;KF5::ConfigWidgets;KF5::IconThemes;KF5::KIOFileWidgets;KF5::KIOWidgets;KF5::Parts;KF5::Notifications;KF5::NotifyConfig;KF5::TextEditor;KF5::ThreadWeaver;KF5::JobWidgets;KF5::ItemViews;KF5::WindowSystem;KF5::KCMUtils;KF5::NewStuff;KF5::Archive;KDev::Debugger;KDev::Project;KDev::Vcs;KDev::Language;KDev::Util;KDev::Documentation"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformShell.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformShell.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Shell )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Shell "${_IMPORT_PREFIX}/lib/libKDevPlatformShell.so.10.0.0" )

# Import target "KDev::Util" for configuration "Release"
set_property(TARGET KDev::Util APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Util PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::ConfigWidgets;KF5::TextEditor;KF5::GuiAddons"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformUtil.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformUtil.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Util )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Util "${_IMPORT_PREFIX}/lib/libKDevPlatformUtil.so.10.0.0" )

# Import target "KDev::OutputView" for configuration "Release"
set_property(TARGET KDev::OutputView APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::OutputView PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformOutputView.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformOutputView.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::OutputView )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::OutputView "${_IMPORT_PREFIX}/lib/libKDevPlatformOutputView.so.10.0.0" )

# Import target "KDev::Vcs" for configuration "Release"
set_property(TARGET KDev::Vcs APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Vcs PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::KIOWidgets;KF5::Parts;KDev::Util"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformVcs.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformVcs.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Vcs )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Vcs "${_IMPORT_PREFIX}/lib/libKDevPlatformVcs.so.10.0.0" )

# Import target "KDev::Debugger" for configuration "Release"
set_property(TARGET KDev::Debugger APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Debugger PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt5::Core;KF5::Notifications;KF5::TextEditor;KDev::Sublime"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformDebugger.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformDebugger.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Debugger )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Debugger "${_IMPORT_PREFIX}/lib/libKDevPlatformDebugger.so.10.0.0" )

# Import target "KDev::Documentation" for configuration "Release"
set_property(TARGET KDev::Documentation APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Documentation PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformDocumentation.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformDocumentation.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Documentation )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Documentation "${_IMPORT_PREFIX}/lib/libKDevPlatformDocumentation.so.10.0.0" )

# Import target "KDev::Serialization" for configuration "Release"
set_property(TARGET KDev::Serialization APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDev::Serialization PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDev::Util"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDevPlatformSerialization.so.10.0.0"
  IMPORTED_SONAME_RELEASE "libKDevPlatformSerialization.so.10"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDev::Serialization )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDev::Serialization "${_IMPORT_PREFIX}/lib/libKDevPlatformSerialization.so.10.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
